@@ -4,6 +4,7 @@ import sys
 from colorama import Fore, Style
 
 from prowler.config.config import (
+    available_compliance_frameworks,
     csv_file_suffix,
     html_file_suffix,
     json_asff_file_suffix,
@@ -11,7 +12,7 @@ from prowler.config.config import (
     orange_color,
 )
 from prowler.lib.logger import logger
-from prowler.lib.outputs.compliance import fill_compliance
+from prowler.lib.outputs.compliance import add_manual_controls, fill_compliance
 from prowler.lib.outputs.file_descriptors import fill_file_descriptors
 from prowler.lib.outputs.html import fill_html
 from prowler.lib.outputs.json import fill_json_asff
@@ -32,7 +33,7 @@ def stdout_report(finding, color, verbose, is_quiet):
     if finding.check_metadata.Provider == "azure":
         details = finding.check_metadata.ServiceName
 
-    if verbose:
+    if verbose and not (is_quiet and finding.status != "FAIL"):
         print(
             f"\t{color}{finding.status}{Style.RESET_ALL} {details}: {finding.status_extended}"
         )
@@ -82,9 +83,9 @@ def report(check_findings, output_options, audit_info):
                     if not (finding.status != "FAIL" and output_options.is_quiet):
                         # AWS specific outputs
                         if finding.check_metadata.Provider == "aws":
-                            if (
-                                "ens_rd2022_aws" in output_options.output_modes
-                                or "cis" in str(output_options.output_modes)
+                            if any(
+                                compliance in output_options.output_modes
+                                for compliance in available_compliance_frameworks
                             ):
                                 fill_compliance(
                                     output_options,
@@ -93,6 +94,12 @@ def report(check_findings, output_options, audit_info):
                                     file_descriptors,
                                 )
 
+                                add_manual_controls(
+                                    output_options,
+                                    audit_info,
+                                    file_descriptors,
+                                )
+
                             if "html" in file_descriptors:
                                 fill_html(file_descriptors["html"], finding)
                                 file_descriptors["html"].write("")
@@ -197,7 +204,9 @@ def send_to_s3_bucket(
         elif output_mode == "html":
             filename = f"{output_filename}{html_file_suffix}"
         logger.info(f"Sending outputs to S3 bucket {output_bucket}")
-        bucket_remote_dir = output_directory.split("/")[-1]
+        bucket_remote_dir = output_directory
+        while "prowler/" in bucket_remote_dir:  # Check if it is not a custom directory
+            bucket_remote_dir = bucket_remote_dir.partition("prowler/")[-1]
         file_name = output_directory + "/" + filename
         bucket_name = output_bucket
         object_name = bucket_remote_dir + "/" + output_mode + "/" + filename
@@ -208,7 +217,7 @@ def send_to_s3_bucket(
         logger.critical(
             f"{error.__class__.__name__}[{error.__traceback__.tb_lineno}] -- {error}"
         )
-        sys.exit()
+        sys.exit(1)
 
 
 def extract_findings_statistics(findings: list) -> dict:
