@@ -1,7 +1,9 @@
 from dataclasses import dataclass
 from datetime import datetime
+from typing import Any, Optional
 
 from boto3 import session
+from botocore.config import Config
 
 
 @dataclass
@@ -32,6 +34,8 @@ class AWS_Organizations_Info:
 class AWS_Audit_Info:
     original_session: session.Session
     audit_session: session.Session
+    # https://boto3.amazonaws.com/v1/documentation/api/latest/guide/retries.html
+    session_config: Config
     audited_account: int
     audited_identity_arn: str
     audited_user_id: str
@@ -41,4 +45,6 @@ class AWS_Audit_Info:
     credentials: AWS_Credentials
     assumed_role_info: AWS_Assume_Role
     audited_regions: list
+    audit_resources: list
     organizations_metadata: AWS_Organizations_Info
+    audit_metadata: Optional[Any] = None
