@@ -1,7 +1,10 @@
 import threading
 from dataclasses import dataclass
 
+from botocore.client import ClientError
+
 from prowler.lib.logger import logger
+from prowler.lib.scan_filters.scan_filters import is_resource_filtered
 from prowler.providers.aws.aws_provider import generate_regional_clients
 
 
@@ -12,6 +15,7 @@ class EC2:
         self.session = audit_info.audit_session
         self.audited_partition = audit_info.audited_partition
         self.audited_account = audit_info.audited_account
+        self.audit_resources = audit_info.audit_resources
         self.regional_clients = generate_regional_clients(self.service, audit_info)
         self.instances = []
         self.__threading_call__(self.__describe_instances__)
@@ -55,41 +59,49 @@ class EC2:
                 for reservation in page["Reservations"]:
                     for instance in reservation["Instances"]:
                         arn = f"arn:{self.audited_partition}:ec2:{regional_client.region}:{self.audited_account}:instance/{instance['InstanceId']}"
-                        http_tokens = None
-                        http_endpoint = None
-                        public_dns = None
-                        public_ip = None
-                        instance_profile = None
-                        if "MetadataOptions" in instance:
-                            http_tokens = instance["MetadataOptions"]["HttpTokens"]
-                            http_endpoint = instance["MetadataOptions"]["HttpEndpoint"]
-                        if (
-                            "PublicDnsName" in instance
-                            and "PublicIpAddress" in instance
+                        if not self.audit_resources or (
+                            is_resource_filtered(arn, self.audit_resources)
                         ):
-                            public_dns = instance["PublicDnsName"]
-                            public_ip = instance["PublicIpAddress"]
-                        if "IamInstanceProfile" in instance:
-                            instance_profile = instance["IamInstanceProfile"]
+                            http_tokens = None
+                            http_endpoint = None
+                            public_dns = None
+                            public_ip = None
+                            private_ip = None
+                            instance_profile = None
+                            if "MetadataOptions" in instance:
+                                http_tokens = instance["MetadataOptions"]["HttpTokens"]
+                                http_endpoint = instance["MetadataOptions"][
+                                    "HttpEndpoint"
+                                ]
+                            if (
+                                "PublicDnsName" in instance
+                                and "PublicIpAddress" in instance
+                            ):
+                                public_dns = instance["PublicDnsName"]
+                                public_ip = instance["PublicIpAddress"]
+                            if "PrivateIpAddress" in instance:
+                                private_ip = instance["PrivateIpAddress"]
+                            if "IamInstanceProfile" in instance:
+                                instance_profile = instance["IamInstanceProfile"]
 
-                        self.instances.append(
-                            Instance(
-                                instance["InstanceId"],
-                                arn,
-                                instance["State"]["Name"],
-                                regional_client.region,
-                                instance["InstanceType"],
-                                instance["ImageId"],
-                                instance["LaunchTime"],
-                                instance["PrivateDnsName"],
-                                instance["PrivateIpAddress"],
-                                public_dns,
-                                public_ip,
-                                http_tokens,
-                                http_endpoint,
-                                instance_profile,
+                            self.instances.append(
+                                Instance(
+                                    instance["InstanceId"],
+                                    arn,
+                                    instance["State"]["Name"],
+                                    regional_client.region,
+                                    instance["InstanceType"],
+                                    instance["ImageId"],
+                                    instance["LaunchTime"],
+                                    instance["PrivateDnsName"],
+                                    private_ip,
+                                    public_dns,
+                                    public_ip,
+                                    http_tokens,
+                                    http_endpoint,
+                                    instance_profile,
+                                )
                             )
-                        )
         except Exception as error:
             logger.error(
                 f"{regional_client.region} -- {error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
@@ -104,16 +116,19 @@ class EC2:
             for page in describe_security_groups_paginator.paginate():
                 for sg in page["SecurityGroups"]:
                     arn = f"arn:{self.audited_partition}:ec2:{regional_client.region}:{self.audited_account}:security-group/{sg['GroupId']}"
-                    self.security_groups.append(
-                        SecurityGroup(
-                            sg["GroupName"],
-                            arn,
-                            regional_client.region,
-                            sg["GroupId"],
-                            sg["IpPermissions"],
-                            sg["IpPermissionsEgress"],
+                    if not self.audit_resources or (
+                        is_resource_filtered(arn, self.audit_resources)
+                    ):
+                        self.security_groups.append(
+                            SecurityGroup(
+                                sg["GroupName"],
+                                arn,
+                                regional_client.region,
+                                sg["GroupId"],
+                                sg["IpPermissions"],
+                                sg["IpPermissionsEgress"],
+                            )
                         )
-                    )
         except Exception as error:
             logger.error(
                 f"{regional_client.region} -- {error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
@@ -128,14 +143,17 @@ class EC2:
             for page in describe_network_acls_paginator.paginate():
                 for nacl in page["NetworkAcls"]:
                     arn = f"arn:{self.audited_partition}:ec2:{regional_client.region}:{self.audited_account}:network-acl/{nacl['NetworkAclId']}"
-                    self.network_acls.append(
-                        NetworkACL(
-                            nacl["NetworkAclId"],
-                            arn,
-                            regional_client.region,
-                            nacl["Entries"],
+                    if not self.audit_resources or (
+                        is_resource_filtered(arn, self.audit_resources)
+                    ):
+                        self.network_acls.append(
+                            NetworkACL(
+                                nacl["NetworkAclId"],
+                                arn,
+                                regional_client.region,
+                                nacl["Entries"],
+                            )
                         )
-                    )
         except Exception as error:
             logger.error(
                 f"{regional_client.region} -- {error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
@@ -151,16 +169,19 @@ class EC2:
             for page in describe_snapshots_paginator.paginate(OwnerIds=["self"]):
                 for snapshot in page["Snapshots"]:
                     arn = f"arn:{self.audited_partition}:ec2:{regional_client.region}:{self.audited_account}:snapshot/{snapshot['SnapshotId']}"
-                    if snapshot["Encrypted"]:
-                        encrypted = True
-                    self.snapshots.append(
-                        Snapshot(
-                            snapshot["SnapshotId"],
-                            arn,
-                            regional_client.region,
-                            encrypted,
+                    if not self.audit_resources or (
+                        is_resource_filtered(arn, self.audit_resources)
+                    ):
+                        if snapshot["Encrypted"]:
+                            encrypted = True
+                        self.snapshots.append(
+                            Snapshot(
+                                snapshot["SnapshotId"],
+                                arn,
+                                regional_client.region,
+                                encrypted,
+                            )
                         )
-                    )
         except Exception as error:
             logger.error(
                 f"{regional_client.region} -- {error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
@@ -220,6 +241,11 @@ class EC2:
                 )["UserData"]
                 if "Value" in user_data:
                     instance.user_data = user_data["Value"]
+        except ClientError as error:
+            if error.response["Error"]["Code"] == "InvalidInstanceID.NotFound":
+                logger.warning(
+                    f"{error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
+                )
         except Exception as error:
             logger.error(
                 f"{error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
@@ -231,17 +257,20 @@ class EC2:
             public = False
             for image in regional_client.describe_images(Owners=["self"])["Images"]:
                 arn = f"arn:{self.audited_partition}:ec2:{regional_client.region}:{self.audited_account}:image/{image['ImageId']}"
-                if image["Public"]:
-                    public = True
-                self.images.append(
-                    Image(
-                        image["ImageId"],
-                        arn,
-                        image["Name"],
-                        public,
-                        regional_client.region,
+                if not self.audit_resources or (
+                    is_resource_filtered(arn, self.audit_resources)
+                ):
+                    if image["Public"]:
+                        public = True
+                    self.images.append(
+                        Image(
+                            image["ImageId"],
+                            arn,
+                            image["Name"],
+                            public,
+                            regional_client.region,
+                        )
                     )
-                )
         except Exception as error:
             logger.error(
                 f"{regional_client.region} -- {error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
@@ -256,14 +285,17 @@ class EC2:
             for page in describe_volumes_paginator.paginate():
                 for volume in page["Volumes"]:
                     arn = f"arn:{self.audited_partition}:ec2:{regional_client.region}:{self.audited_account}:volume/{volume['VolumeId']}"
-                    self.volumes.append(
-                        Volume(
-                            volume["VolumeId"],
-                            arn,
-                            regional_client.region,
-                            volume["Encrypted"],
+                    if not self.audit_resources or (
+                        is_resource_filtered(arn, self.audit_resources)
+                    ):
+                        self.volumes.append(
+                            Volume(
+                                volume["VolumeId"],
+                                arn,
+                                regional_client.region,
+                                volume["Encrypted"],
+                            )
                         )
-                    )
         except Exception as error:
             logger.error(
                 f"{regional_client.region} -- {error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
@@ -283,16 +315,18 @@ class EC2:
                 if "AllocationId" in address:
                     allocation_id = address["AllocationId"]
                 elastic_ip_arn = f"arn:{self.audited_partition}:ec2:{regional_client.region}:{self.audited_account}:eip-allocation/{allocation_id}"
-
-                self.elastic_ips.append(
-                    ElasticIP(
-                        public_ip,
-                        association_id,
-                        allocation_id,
-                        elastic_ip_arn,
-                        regional_client.region,
+                if not self.audit_resources or (
+                    is_resource_filtered(elastic_ip_arn, self.audit_resources)
+                ):
+                    self.elastic_ips.append(
+                        ElasticIP(
+                            public_ip,
+                            association_id,
+                            allocation_id,
+                            elastic_ip_arn,
+                            regional_client.region,
+                        )
                     )
-                )
         except Exception as error:
             logger.error(
                 f"{regional_client.region} -- {error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
